==> lkstlogtools-1.0.1.tar.gz: lkstlogtools-1.0.1/include/extra_etypes.h <==
/*
 LKST extra event types header
  
 Copyright (C) HITACHI,LTD. 2005
 WRITTEN BY HITACHI SYSTEMS DEVELOPMENT LABORATORY,
 Created by M.Hiramatsu <hiramatu@sdl.hitachi.co.jp>
  
 The development of this program is partly supported by IPA
 (Information-Technology Promotion Agency, Japan).
  
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

#define EID_PROCESS_CNT_WQ 0xef0
#define EID_MEM_VM_INFO  0xef1
#define EID_FS_STAT_INFO 0xef2
#define EID_SYSTEM_INFO  0xef3
#define EID_PROCESS_CONTEXTSW2 0xefa
#define EID_PROCESS_WAKEUP2 0xefb
#ifndef __KERNEL__
#define LKST_ETYPE_PROCESS_CNT_WQ EID_PROCESS_CNT_WQ
#define LKST_ETYPE_MEM_VM_INFO EID_MEM_VM_INFO
#define LKST_ETYPE_FS_STAT_INFO EID_FS_STAT_INFO
#define LKST_ETYPE_SYSTEM_INFO EID_SYSTEM_INFO
#define LKST_ETYPE_PROCESS_CONTEXTSW2 EID_PROCESS_CONTEXTSW2
#define LKST_ETYPE_PROCESS_WAKEUP2 EID_PROCESS_WAKEUP2
#endif

==> lkstlogtools-1.1.0.tar.gz: lkstlogtools-1.1.0/include/extra_etypes.h <==
/*
 LKST extra event types header
  
 Copyright (C) HITACHI,LTD. 2005
 WRITTEN BY HITACHI SYSTEMS DEVELOPMENT LABORATORY,
 Created by M.Hiramatsu <hiramatu@sdl.hitachi.co.jp>
  
 The development of this program is partly supported by IPA
 (Information-Technology Promotion Agency, Japan).
  
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

#define EID_PROCESS_CNT_WQ 0xef0
#define EID_MEM_VM_INFO  0xef1
//#define EID_FS_STAT_INFO 0xef2
#define EID_MEM_VM_INFO2 0xef2
#define EID_SYSTEM_INFO  0xef3
#define EID_SYSTEM_INFO2 0xef4
#define EID_PROCESS_CONTEXTSW2 0xefa
#define EID_PROCESS_WAKEUP2 0xefb
#ifndef __KERNEL__
#define LKST_ETYPE_PROCESS_CNT_WQ EID_PROCESS_CNT_WQ
#define LKST_ETYPE_MEM_VM_INFO EID_MEM_VM_INFO
#define LKST_ETYPE_MEM_VM_INFO2 EID_MEM_VM_INFO2
//#define LKST_ETYPE_FS_STAT_INFO EID_FS_STAT_INFO
#define LKST_ETYPE_SYSTEM_INFO EID_SYSTEM_INFO
#define LKST_ETYPE_SYSTEM_INFO2 EID_SYSTEM_INFO2
#define LKST_ETYPE_PROCESS_CONTEXTSW2 EID_PROCESS_CONTEXTSW2
#define LKST_ETYPE_PROCESS_WAKEUP2 EID_PROCESS_WAKEUP2
#endif
